@@ -17,7 +17,7 @@ def rings(features_X, features_position, criteria="k", max_radios=[200, 300, 400
     # Verificar que ambas listas sean de largo igual
     assert len(max_radios) == len(max_neighbours)
 
-    points = list(zip(features_position.lon, features_position.lat))
+    points = np.array(list(zip(features_position.lon, features_position.lat)))
     tree = spatial.KDTree(data=points, leafsize=leafsize)
     final_features_df = pd.DataFrame()
 
